"""expand workflow definitions

Revision ID: 2b6fb28c98cb
Revises: 8605707dacc8
Create Date: 2022-10-17 13:09:35.571085

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "2b6fb28c98cb"
down_revision = "8605707dacc8"
branch_labels = None
depends_on = None

lustre = [
    "ingest_image",
    "ingest_cal",
    "carta",
    "test_download",
    "pims_split",
    "ingest_seci",
    "vlass_image_caching",
    "qa_fail",
]
remote = [
    "std_calibration",
    "std_cms_imaging",
    "std_restore_imaging",
    "restore_cms",
    "test_download",
    "carta",
    "vlass_calibration",
    "vlass_quicklook",
    "vlass_coarse",
    "vlass_seci",
    "null",
    "null_dag",
]
external = [
    "carta",
    "vlass_calibration",
    "vlass_quicklook",
    "vlass_coarse",
    "vlass_image_caching",
    "vlass_seci",
    "pims_split",
    "ingest_seci",
]


def upgrade():
    op.add_column(
        "workflows",
        sa.Column(
            "requires_lustre",
            sa.Boolean,
            server_default="False",
            nullable=False,
            comment="does this entire workflow require lustre access? (downloads, ingestion, etc.)",
        ),
    )
    op.add_column(
        "workflows",
        sa.Column(
            "remote_capable",
            sa.Boolean,
            server_default="False",
            nullable=False,
            comment="can this workflow (or part of this workflow) run remote?",
        ),
    )
    op.add_column(
        "workflows",
        sa.Column(
            "external_wf",
            sa.Boolean,
            server_default="False",
            nullable=False,
            comment="is this workflow initiated outside of Workspaces or does it need to report "
            "to another system? (Archive, VLASS, etc.)",
        ),
    )
    op.create_table(
        "processing_sites",
        sa.Column(
            "processing_site",
            sa.String,
            primary_key=True,
            comment="the abbreviation of the processing site (NMT, NAASC, etc.)",
        ),
        sa.Column(
            "template_key",
            sa.String,
            nullable=True,
            comment="the key used by WS template rendering to ensure correct site setup",
        ),
        sa.Column(
            "data_center",
            sa.Boolean,
            server_default="False",
            nullable=False,
            comment="is this site also a data retrieval site? (DSOC, NAASC, etc.)",
        ),
    )

    # Populate table
    op.execute(
        """
        INSERT INTO processing_sites (processing_site, template_key, data_center)
        VALUES ('DSOC',null, true)
        """
    )
    op.execute(
        """
        INSERT INTO processing_sites (processing_site, template_key, data_center)
        VALUES ('NAASC','remote-cv', true)
        """
    )
    op.execute(
        """
        INSERT INTO processing_sites (processing_site, template_key, data_center)
        VALUES ('NMT','remote', false)
        """
    )

    # Populate wf definition columns
    for wf in lustre:
        op.execute(
            f"""
            UPDATE workflows
            SET requires_lustre=true
            WHERE workflow_name='{wf}'
            """
        )
    for wf in remote:
        op.execute(
            f"""
            UPDATE workflows
            SET remote_capable=true
            WHERE workflow_name='{wf}'
            """
        )
    for wf in external:
        op.execute(
            f"""
            UPDATE workflows
            SET external_wf=true
            WHERE workflow_name='{wf}'
            """
        )


def downgrade():
    op.drop_column("workflows", "requires_lustre")
    op.drop_column("workflows", "remote_capable")
    op.drop_column("workflows", "external_wf")
    op.drop_table("processing_sites")
